==> alibabacloud_tdsr20200101_py2-3.1.4.tar.gz: alibabacloud_tdsr20200101_py2-3.1.4/ChangeLog.md <==
2022-05-27 Version: 3.1.3
- Add  Model CoverUrl.

2022-05-25 Version: 3.1.2
- Add  Rebuild Params with Rebuild  Interface And Pack Scene Origin Image Interface.

2022-05-23 Version: 3.1.1
- Add  Rebuild Params with Rebuild  Interface.

2022-05-13 Version: 3.1.0
- Modify  Some  Interface.

2022-05-10 Version: 3.0.10
- Modify  Failed Type Within GetScenePackUrl And GetPackSceneTaskStatus  Interface.

2022-05-09 Version: 3.0.9
- Add Model Pack Interface.

2022-04-25 Version: 3.0.8
- Add Model Preview Interface.

2022-03-10 Version: 3.0.7
- Add CheckUserProperty Interface.

2022-02-17 Version: 3.0.6
- Add GetScenePreviewData Interface.

2022-01-06 Version: 3.0.5
- Modify DetailSubScene interface API Response Field.

2021-12-24 Version: 3.0.4
- Add addRoomPlan interface.

2021-11-26 Version: 3.0.3
- Add mix scene.

2021-11-16 Version: 3.0.2
- Modify Some Interface.

2021-11-16 Version: 3.0.1
- Modify Some Interface.

2021-11-01 Version: 3.0.0
- Modify ListSubScene Interface.

2021-10-25 Version: 2.2.10
- Add addMosaics Interface.

2021-09-29 Version: 2.2.9
- LinkImage Add params.
- ListSubScene Add Result Filed.

2021-09-15 Version: 2.2.8
- LabelBuild Interface  Add Rebuild Mode.

2021-08-24 Version: 2.2.7
- GetHotspotTag Add Params .

2021-08-23 Version: 2.2.6
- GetHotspotTag .
- GetHotspotConfig.
- DetailSubScene.
- ListSubScene.

2021-08-10 Version: 2.2.5
- Add GetScenePreviewInfo Interface.
- Add GetHotspotSceneData Interface.

2021-07-20 Version: 2.2.4
- Temppreview interface parameter name change.

2021-07-16 Version: 2.2.3
- New task query status interface.
- Parameter change returned by publishing interface.

2021-06-15 Version: 2.2.2
- Add a new relative position interface to allow users to adjust the position of each scene before submitting.

2021-06-02 Version: 2.2.1
- Add apis.

==> alibabacloud_tdsr20200101_py2-3.1.7.tar.gz: alibabacloud_tdsr20200101_py2-3.1.7/ChangeLog.md <==
2022-07-26 Version: 3.1.5
- Add  Hotspot  File Interface.

2022-07-25 Version: 3.1.4
- Add  Hotspot Interface.

2022-05-27 Version: 3.1.3
- Add  Model CoverUrl.

2022-05-25 Version: 3.1.2
- Add  Rebuild Params with Rebuild  Interface And Pack Scene Origin Image Interface.

2022-05-23 Version: 3.1.1
- Add  Rebuild Params with Rebuild  Interface.

2022-05-13 Version: 3.1.0
- Modify  Some  Interface.

2022-05-10 Version: 3.0.10
- Modify  Failed Type Within GetScenePackUrl And GetPackSceneTaskStatus  Interface.

2022-05-09 Version: 3.0.9
- Add Model Pack Interface.

2022-04-25 Version: 3.0.8
- Add Model Preview Interface.

2022-03-10 Version: 3.0.7
- Add CheckUserProperty Interface.

2022-02-17 Version: 3.0.6
- Add GetScenePreviewData Interface.

2022-01-06 Version: 3.0.5
- Modify DetailSubScene interface API Response Field.

2021-12-24 Version: 3.0.4
- Add addRoomPlan interface.

2021-11-26 Version: 3.0.3
- Add mix scene.

2021-11-16 Version: 3.0.2
- Modify Some Interface.

2021-11-16 Version: 3.0.1
- Modify Some Interface.

2021-11-01 Version: 3.0.0
- Modify ListSubScene Interface.

2021-10-25 Version: 2.2.10
- Add addMosaics Interface.

2021-09-29 Version: 2.2.9
- LinkImage Add params.
- ListSubScene Add Result Filed.

2021-09-15 Version: 2.2.8
- LabelBuild Interface  Add Rebuild Mode.

2021-08-24 Version: 2.2.7
- GetHotspotTag Add Params .

2021-08-23 Version: 2.2.6
- GetHotspotTag .
- GetHotspotConfig.
- DetailSubScene.
- ListSubScene.

2021-08-10 Version: 2.2.5
- Add GetScenePreviewInfo Interface.
- Add GetHotspotSceneData Interface.

2021-07-20 Version: 2.2.4
- Temppreview interface parameter name change.

2021-07-16 Version: 2.2.3
- New task query status interface.
- Parameter change returned by publishing interface.

2021-06-15 Version: 2.2.2
- Add a new relative position interface to allow users to adjust the position of each scene before submitting.

2021-06-02 Version: 2.2.1
- Add apis.
